@@ -9,7 +9,7 @@ use Role::Tiny::With;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-15'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.022'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 with 'TableDataRole::Source::CSVInDATA';
 
@@ -26,7 +26,37 @@ TableData::Sample::DeNiro - Rotten Tomato ratings of movies with Robert De Niro
 
 =head1 VERSION
 
-This document describes version 0.022 of TableData::Sample::DeNiro (from Perl distribution TableDataRoles-Standard), released on 2024-01-15.
+This document describes version 0.023 of TableData::Sample::DeNiro (from Perl distribution TableDataRoles-Standard), released on 2024-01-15.
+
+=head1 SYNOPSIS
+
+To use from Perl code:
+
+ use TableData::Sample::DeNiro;
+
+ my $td = TableData::Sample::DeNiro->new;
+
+ # Iterate rows of the table
+ $td->each_row_arrayref(sub { my $row = shift; ... });
+ $td->each_row_hashref (sub { my $row = shift; ... });
+
+ # Get the list of column names
+ my @columns = $td->get_column_names;
+
+ # Get the number of rows
+ my $row_count = $td->get_row_count;
+
+See also L<TableDataRole::Spec::Basic> for other methods.
+
+To use from command-line (using L<tabledata> CLI):
+
+ # Display as ASCII table and view with pager
+ % tabledata Sample::DeNiro --page
+
+ # Get number of rows
+ % tabledata --action count_rows Sample::DeNiro
+
+See the L<tabledata> CLI's documentation for other available actions and options.
 
 =head1 HOMEPAGE
 
@@ -36,6 +66,12 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableDataR
 
 Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Standard>.
 
+=head1 SEE ALSO
+
+L<ArrayData::Sample::DeNiro>
+
+L<HashData::Sample::DeNiro>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
